package Bencher::Scenarios::TextTableTiny;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-08-08'; # DATE
our $DIST = 'Bencher-Scenarios-TextTableTiny'; # DIST
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Scenarios for benchmarking Text::Table::Tiny

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::TextTableTiny - Scenarios for benchmarking Text::Table::Tiny

=head1 VERSION

This document describes version 0.002 of Bencher::Scenarios::TextTableTiny (from Perl distribution Bencher-Scenarios-TextTableTiny), released on 2020-08-08.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::TextTableTiny::Startup>

=item * L<Bencher::Scenario::TextTableTiny::Render>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-TextTableTiny>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-TextTableTiny>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-TextTableTiny>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
